# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceConfigurationLaunchInstanceDetails(object):
    """
    Instance launch details for creating an instance from an instance configuration. Use the `sourceDetails`
    parameter to specify whether a boot volume or an image should be used to launch a new instance.

    See :class:`LaunchInstanceDetails` for more information.
    """

    #: A constant which can be used with the launch_mode property of a InstanceConfigurationLaunchInstanceDetails.
    #: This constant has a value of "NATIVE"
    LAUNCH_MODE_NATIVE = "NATIVE"

    #: A constant which can be used with the launch_mode property of a InstanceConfigurationLaunchInstanceDetails.
    #: This constant has a value of "EMULATED"
    LAUNCH_MODE_EMULATED = "EMULATED"

    #: A constant which can be used with the launch_mode property of a InstanceConfigurationLaunchInstanceDetails.
    #: This constant has a value of "PARAVIRTUALIZED"
    LAUNCH_MODE_PARAVIRTUALIZED = "PARAVIRTUALIZED"

    #: A constant which can be used with the launch_mode property of a InstanceConfigurationLaunchInstanceDetails.
    #: This constant has a value of "CUSTOM"
    LAUNCH_MODE_CUSTOM = "CUSTOM"

    #: A constant which can be used with the preferred_maintenance_action property of a InstanceConfigurationLaunchInstanceDetails.
    #: This constant has a value of "LIVE_MIGRATE"
    PREFERRED_MAINTENANCE_ACTION_LIVE_MIGRATE = "LIVE_MIGRATE"

    #: A constant which can be used with the preferred_maintenance_action property of a InstanceConfigurationLaunchInstanceDetails.
    #: This constant has a value of "REBOOT"
    PREFERRED_MAINTENANCE_ACTION_REBOOT = "REBOOT"

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceConfigurationLaunchInstanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this InstanceConfigurationLaunchInstanceDetails.
        :type availability_domain: str

        :param compartment_id:
            The value to assign to the compartment_id property of this InstanceConfigurationLaunchInstanceDetails.
        :type compartment_id: str

        :param create_vnic_details:
            The value to assign to the create_vnic_details property of this InstanceConfigurationLaunchInstanceDetails.
        :type create_vnic_details: InstanceConfigurationCreateVnicDetails

        :param defined_tags:
            The value to assign to the defined_tags property of this InstanceConfigurationLaunchInstanceDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this InstanceConfigurationLaunchInstanceDetails.
        :type display_name: str

        :param extended_metadata:
            The value to assign to the extended_metadata property of this InstanceConfigurationLaunchInstanceDetails.
        :type extended_metadata: dict(str, object)

        :param freeform_tags:
            The value to assign to the freeform_tags property of this InstanceConfigurationLaunchInstanceDetails.
        :type freeform_tags: dict(str, str)

        :param ipxe_script:
            The value to assign to the ipxe_script property of this InstanceConfigurationLaunchInstanceDetails.
        :type ipxe_script: str

        :param metadata:
            The value to assign to the metadata property of this InstanceConfigurationLaunchInstanceDetails.
        :type metadata: dict(str, str)

        :param shape:
            The value to assign to the shape property of this InstanceConfigurationLaunchInstanceDetails.
        :type shape: str

        :param shape_config:
            The value to assign to the shape_config property of this InstanceConfigurationLaunchInstanceDetails.
        :type shape_config: InstanceConfigurationLaunchInstanceShapeConfigDetails

        :param source_details:
            The value to assign to the source_details property of this InstanceConfigurationLaunchInstanceDetails.
        :type source_details: InstanceConfigurationInstanceSourceDetails

        :param fault_domain:
            The value to assign to the fault_domain property of this InstanceConfigurationLaunchInstanceDetails.
        :type fault_domain: str

        :param dedicated_vm_host_id:
            The value to assign to the dedicated_vm_host_id property of this InstanceConfigurationLaunchInstanceDetails.
        :type dedicated_vm_host_id: str

        :param launch_mode:
            The value to assign to the launch_mode property of this InstanceConfigurationLaunchInstanceDetails.
            Allowed values for this property are: "NATIVE", "EMULATED", "PARAVIRTUALIZED", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type launch_mode: str

        :param launch_options:
            The value to assign to the launch_options property of this InstanceConfigurationLaunchInstanceDetails.
        :type launch_options: InstanceConfigurationLaunchOptions

        :param agent_config:
            The value to assign to the agent_config property of this InstanceConfigurationLaunchInstanceDetails.
        :type agent_config: InstanceConfigurationLaunchInstanceAgentConfigDetails

        :param is_pv_encryption_in_transit_enabled:
            The value to assign to the is_pv_encryption_in_transit_enabled property of this InstanceConfigurationLaunchInstanceDetails.
        :type is_pv_encryption_in_transit_enabled: bool

        :param preferred_maintenance_action:
            The value to assign to the preferred_maintenance_action property of this InstanceConfigurationLaunchInstanceDetails.
            Allowed values for this property are: "LIVE_MIGRATE", "REBOOT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type preferred_maintenance_action: str

        :param availability_config:
            The value to assign to the availability_config property of this InstanceConfigurationLaunchInstanceDetails.
        :type availability_config: InstanceConfigurationAvailabilityConfig

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'compartment_id': 'str',
            'create_vnic_details': 'InstanceConfigurationCreateVnicDetails',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'extended_metadata': 'dict(str, object)',
            'freeform_tags': 'dict(str, str)',
            'ipxe_script': 'str',
            'metadata': 'dict(str, str)',
            'shape': 'str',
            'shape_config': 'InstanceConfigurationLaunchInstanceShapeConfigDetails',
            'source_details': 'InstanceConfigurationInstanceSourceDetails',
            'fault_domain': 'str',
            'dedicated_vm_host_id': 'str',
            'launch_mode': 'str',
            'launch_options': 'InstanceConfigurationLaunchOptions',
            'agent_config': 'InstanceConfigurationLaunchInstanceAgentConfigDetails',
            'is_pv_encryption_in_transit_enabled': 'bool',
            'preferred_maintenance_action': 'str',
            'availability_config': 'InstanceConfigurationAvailabilityConfig'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'compartment_id': 'compartmentId',
            'create_vnic_details': 'createVnicDetails',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'extended_metadata': 'extendedMetadata',
            'freeform_tags': 'freeformTags',
            'ipxe_script': 'ipxeScript',
            'metadata': 'metadata',
            'shape': 'shape',
            'shape_config': 'shapeConfig',
            'source_details': 'sourceDetails',
            'fault_domain': 'faultDomain',
            'dedicated_vm_host_id': 'dedicatedVmHostId',
            'launch_mode': 'launchMode',
            'launch_options': 'launchOptions',
            'agent_config': 'agentConfig',
            'is_pv_encryption_in_transit_enabled': 'isPvEncryptionInTransitEnabled',
            'preferred_maintenance_action': 'preferredMaintenanceAction',
            'availability_config': 'availabilityConfig'
        }

        self._availability_domain = None
        self._compartment_id = None
        self._create_vnic_details = None
        self._defined_tags = None
        self._display_name = None
        self._extended_metadata = None
        self._freeform_tags = None
        self._ipxe_script = None
        self._metadata = None
        self._shape = None
        self._shape_config = None
        self._source_details = None
        self._fault_domain = None
        self._dedicated_vm_host_id = None
        self._launch_mode = None
        self._launch_options = None
        self._agent_config = None
        self._is_pv_encryption_in_transit_enabled = None
        self._preferred_maintenance_action = None
        self._availability_config = None

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this InstanceConfigurationLaunchInstanceDetails.
        The availability domain of the instance.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this InstanceConfigurationLaunchInstanceDetails.
        The availability domain of the instance.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this InstanceConfigurationLaunchInstanceDetails.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this InstanceConfigurationLaunchInstanceDetails.
        The OCID of the compartment.


        :return: The compartment_id of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this InstanceConfigurationLaunchInstanceDetails.
        The OCID of the compartment.


        :param compartment_id: The compartment_id of this InstanceConfigurationLaunchInstanceDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def create_vnic_details(self):
        """
        Gets the create_vnic_details of this InstanceConfigurationLaunchInstanceDetails.
        Details for the primary VNIC, which is automatically created and attached when
        the instance is launched.


        :return: The create_vnic_details of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: InstanceConfigurationCreateVnicDetails
        """
        return self._create_vnic_details

    @create_vnic_details.setter
    def create_vnic_details(self, create_vnic_details):
        """
        Sets the create_vnic_details of this InstanceConfigurationLaunchInstanceDetails.
        Details for the primary VNIC, which is automatically created and attached when
        the instance is launched.


        :param create_vnic_details: The create_vnic_details of this InstanceConfigurationLaunchInstanceDetails.
        :type: InstanceConfigurationCreateVnicDetails
        """
        self._create_vnic_details = create_vnic_details

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this InstanceConfigurationLaunchInstanceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this InstanceConfigurationLaunchInstanceDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this InstanceConfigurationLaunchInstanceDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this InstanceConfigurationLaunchInstanceDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.

        Example: `My bare metal instance`


        :return: The display_name of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this InstanceConfigurationLaunchInstanceDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.

        Example: `My bare metal instance`


        :param display_name: The display_name of this InstanceConfigurationLaunchInstanceDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def extended_metadata(self):
        """
        Gets the extended_metadata of this InstanceConfigurationLaunchInstanceDetails.
        Additional metadata key/value pairs that you provide. They serve the same purpose and
        functionality as fields in the `metadata` object.

        They are distinguished from `metadata` fields in that these can be nested JSON objects
        (whereas `metadata` fields are string/string maps only).

        The combined size of the `metadata` and `extendedMetadata` objects can be a maximum of
        32,000 bytes.


        :return: The extended_metadata of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: dict(str, object)
        """
        return self._extended_metadata

    @extended_metadata.setter
    def extended_metadata(self, extended_metadata):
        """
        Sets the extended_metadata of this InstanceConfigurationLaunchInstanceDetails.
        Additional metadata key/value pairs that you provide. They serve the same purpose and
        functionality as fields in the `metadata` object.

        They are distinguished from `metadata` fields in that these can be nested JSON objects
        (whereas `metadata` fields are string/string maps only).

        The combined size of the `metadata` and `extendedMetadata` objects can be a maximum of
        32,000 bytes.


        :param extended_metadata: The extended_metadata of this InstanceConfigurationLaunchInstanceDetails.
        :type: dict(str, object)
        """
        self._extended_metadata = extended_metadata

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this InstanceConfigurationLaunchInstanceDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this InstanceConfigurationLaunchInstanceDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this InstanceConfigurationLaunchInstanceDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def ipxe_script(self):
        """
        Gets the ipxe_script of this InstanceConfigurationLaunchInstanceDetails.
        This is an advanced option.

        When a bare metal or virtual machine
        instance boots, the iPXE firmware that runs on the instance is
        configured to run an iPXE script to continue the boot process.

        If you want more control over the boot process, you can provide
        your own custom iPXE script that will run when the instance boots;
        however, you should be aware that the same iPXE script will run
        every time an instance boots; not only after the initial
        LaunchInstance call.

        The default iPXE script connects to the instance's local boot
        volume over iSCSI and performs a network boot. If you use a custom iPXE
        script and want to network-boot from the instance's local boot volume
        over iSCSI the same way as the default iPXE script, you should use the
        following iSCSI IP address: 169.254.0.2, and boot volume IQN:
        iqn.2015-02.oracle.boot.

        For more information about the Bring Your Own Image feature of
        Oracle Cloud Infrastructure, see
        `Bring Your Own Image`__.

        For more information about iPXE, see http://ipxe.org.

        __ https://docs.cloud.oracle.com/Content/Compute/References/bringyourownimage.htm


        :return: The ipxe_script of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: str
        """
        return self._ipxe_script

    @ipxe_script.setter
    def ipxe_script(self, ipxe_script):
        """
        Sets the ipxe_script of this InstanceConfigurationLaunchInstanceDetails.
        This is an advanced option.

        When a bare metal or virtual machine
        instance boots, the iPXE firmware that runs on the instance is
        configured to run an iPXE script to continue the boot process.

        If you want more control over the boot process, you can provide
        your own custom iPXE script that will run when the instance boots;
        however, you should be aware that the same iPXE script will run
        every time an instance boots; not only after the initial
        LaunchInstance call.

        The default iPXE script connects to the instance's local boot
        volume over iSCSI and performs a network boot. If you use a custom iPXE
        script and want to network-boot from the instance's local boot volume
        over iSCSI the same way as the default iPXE script, you should use the
        following iSCSI IP address: 169.254.0.2, and boot volume IQN:
        iqn.2015-02.oracle.boot.

        For more information about the Bring Your Own Image feature of
        Oracle Cloud Infrastructure, see
        `Bring Your Own Image`__.

        For more information about iPXE, see http://ipxe.org.

        __ https://docs.cloud.oracle.com/Content/Compute/References/bringyourownimage.htm


        :param ipxe_script: The ipxe_script of this InstanceConfigurationLaunchInstanceDetails.
        :type: str
        """
        self._ipxe_script = ipxe_script

    @property
    def metadata(self):
        """
        Gets the metadata of this InstanceConfigurationLaunchInstanceDetails.
        Custom metadata key/value pairs that you provide, such as the SSH public key
        required to connect to the instance.

        A metadata service runs on every launched instance. The service is an HTTP
        endpoint listening on 169.254.169.254. You can use the service to:

        * Provide information to `Cloud-Init`__
          to be used for various system initialization tasks.

        * Get information about the instance, including the custom metadata that you
          provide when you launch the instance.

         **Providing Cloud-Init Metadata**

         You can use the following metadata key names to provide information to
         Cloud-Init:

         **\"ssh_authorized_keys\"** - Provide one or more public SSH keys to be
         included in the `~/.ssh/authorized_keys` file for the default user on the
         instance. Use a newline character to separate multiple keys. The SSH
         keys must be in the format necessary for the `authorized_keys` file, as shown
         in the example below.

         **\"user_data\"** - Provide your own base64-encoded data to be used by
         Cloud-Init to run custom scripts or provide custom Cloud-Init configuration. For
         information about how to take advantage of user data, see the
         `Cloud-Init Documentation`__.

         **Metadata Example**

              \"metadata\" : {
                 \"quake_bot_level\" : \"Severe\",
                 \"ssh_authorized_keys\" : \"ssh-rsa <your_public_SSH_key>== rsa-key-20160227\",
                 \"user_data\" : \"<your_public_SSH_key>==\"
              }
         **Getting Metadata on the Instance**

         To get information about your instance, connect to the instance using SSH and issue any of the
         following GET requests:

             curl -H \"Authorization: Bearer Oracle\" http://169.254.169.254/opc/v2/instance/
             curl -H \"Authorization: Bearer Oracle\" http://169.254.169.254/opc/v2/instance/metadata/
             curl -H \"Authorization: Bearer Oracle\" http://169.254.169.254/opc/v2/instance/metadata/<any-key-name>

         You'll get back a response that includes all the instance information; only the metadata information; or
         the metadata information for the specified key name, respectively.

         The combined size of the `metadata` and `extendedMetadata` objects can be a maximum of 32,000 bytes.

        __ https://cloudinit.readthedocs.org/en/latest/
        __ http://cloudinit.readthedocs.org/en/latest/topics/format.html


        :return: The metadata of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this InstanceConfigurationLaunchInstanceDetails.
        Custom metadata key/value pairs that you provide, such as the SSH public key
        required to connect to the instance.

        A metadata service runs on every launched instance. The service is an HTTP
        endpoint listening on 169.254.169.254. You can use the service to:

        * Provide information to `Cloud-Init`__
          to be used for various system initialization tasks.

        * Get information about the instance, including the custom metadata that you
          provide when you launch the instance.

         **Providing Cloud-Init Metadata**

         You can use the following metadata key names to provide information to
         Cloud-Init:

         **\"ssh_authorized_keys\"** - Provide one or more public SSH keys to be
         included in the `~/.ssh/authorized_keys` file for the default user on the
         instance. Use a newline character to separate multiple keys. The SSH
         keys must be in the format necessary for the `authorized_keys` file, as shown
         in the example below.

         **\"user_data\"** - Provide your own base64-encoded data to be used by
         Cloud-Init to run custom scripts or provide custom Cloud-Init configuration. For
         information about how to take advantage of user data, see the
         `Cloud-Init Documentation`__.

         **Metadata Example**

              \"metadata\" : {
                 \"quake_bot_level\" : \"Severe\",
                 \"ssh_authorized_keys\" : \"ssh-rsa <your_public_SSH_key>== rsa-key-20160227\",
                 \"user_data\" : \"<your_public_SSH_key>==\"
              }
         **Getting Metadata on the Instance**

         To get information about your instance, connect to the instance using SSH and issue any of the
         following GET requests:

             curl -H \"Authorization: Bearer Oracle\" http://169.254.169.254/opc/v2/instance/
             curl -H \"Authorization: Bearer Oracle\" http://169.254.169.254/opc/v2/instance/metadata/
             curl -H \"Authorization: Bearer Oracle\" http://169.254.169.254/opc/v2/instance/metadata/<any-key-name>

         You'll get back a response that includes all the instance information; only the metadata information; or
         the metadata information for the specified key name, respectively.

         The combined size of the `metadata` and `extendedMetadata` objects can be a maximum of 32,000 bytes.

        __ https://cloudinit.readthedocs.org/en/latest/
        __ http://cloudinit.readthedocs.org/en/latest/topics/format.html


        :param metadata: The metadata of this InstanceConfigurationLaunchInstanceDetails.
        :type: dict(str, str)
        """
        self._metadata = metadata

    @property
    def shape(self):
        """
        Gets the shape of this InstanceConfigurationLaunchInstanceDetails.
        The shape of an instance. The shape determines the number of CPUs, amount of memory,
        and other resources allocated to the instance.

        You can enumerate all available shapes by calling :func:`list_shapes`.


        :return: The shape of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this InstanceConfigurationLaunchInstanceDetails.
        The shape of an instance. The shape determines the number of CPUs, amount of memory,
        and other resources allocated to the instance.

        You can enumerate all available shapes by calling :func:`list_shapes`.


        :param shape: The shape of this InstanceConfigurationLaunchInstanceDetails.
        :type: str
        """
        self._shape = shape

    @property
    def shape_config(self):
        """
        Gets the shape_config of this InstanceConfigurationLaunchInstanceDetails.

        :return: The shape_config of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: InstanceConfigurationLaunchInstanceShapeConfigDetails
        """
        return self._shape_config

    @shape_config.setter
    def shape_config(self, shape_config):
        """
        Sets the shape_config of this InstanceConfigurationLaunchInstanceDetails.

        :param shape_config: The shape_config of this InstanceConfigurationLaunchInstanceDetails.
        :type: InstanceConfigurationLaunchInstanceShapeConfigDetails
        """
        self._shape_config = shape_config

    @property
    def source_details(self):
        """
        Gets the source_details of this InstanceConfigurationLaunchInstanceDetails.
        Details for creating an instance.
        Use this parameter to specify whether a boot volume or an image should be used to launch a new instance.


        :return: The source_details of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: InstanceConfigurationInstanceSourceDetails
        """
        return self._source_details

    @source_details.setter
    def source_details(self, source_details):
        """
        Sets the source_details of this InstanceConfigurationLaunchInstanceDetails.
        Details for creating an instance.
        Use this parameter to specify whether a boot volume or an image should be used to launch a new instance.


        :param source_details: The source_details of this InstanceConfigurationLaunchInstanceDetails.
        :type: InstanceConfigurationInstanceSourceDetails
        """
        self._source_details = source_details

    @property
    def fault_domain(self):
        """
        Gets the fault_domain of this InstanceConfigurationLaunchInstanceDetails.
        A fault domain is a grouping of hardware and infrastructure within an availability domain.
        Each availability domain contains three fault domains. Fault domains let you distribute your
        instances so that they are not on the same physical hardware within a single availability domain.
        A hardware failure or Compute hardware maintenance that affects one fault domain does not affect
        instances in other fault domains.

        If you do not specify the fault domain, the system selects one for you.


        To get a list of fault domains, use the
        :func:`list_fault_domains` operation in the
        Identity and Access Management Service API.

        Example: `FAULT-DOMAIN-1`


        :return: The fault_domain of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """
        Sets the fault_domain of this InstanceConfigurationLaunchInstanceDetails.
        A fault domain is a grouping of hardware and infrastructure within an availability domain.
        Each availability domain contains three fault domains. Fault domains let you distribute your
        instances so that they are not on the same physical hardware within a single availability domain.
        A hardware failure or Compute hardware maintenance that affects one fault domain does not affect
        instances in other fault domains.

        If you do not specify the fault domain, the system selects one for you.


        To get a list of fault domains, use the
        :func:`list_fault_domains` operation in the
        Identity and Access Management Service API.

        Example: `FAULT-DOMAIN-1`


        :param fault_domain: The fault_domain of this InstanceConfigurationLaunchInstanceDetails.
        :type: str
        """
        self._fault_domain = fault_domain

    @property
    def dedicated_vm_host_id(self):
        """
        Gets the dedicated_vm_host_id of this InstanceConfigurationLaunchInstanceDetails.
        The OCID of dedicated VM host.

        Dedicated VM hosts can be used when launching individual instances from an instance configuration. They
        cannot be used to launch instance pools.


        :return: The dedicated_vm_host_id of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: str
        """
        return self._dedicated_vm_host_id

    @dedicated_vm_host_id.setter
    def dedicated_vm_host_id(self, dedicated_vm_host_id):
        """
        Sets the dedicated_vm_host_id of this InstanceConfigurationLaunchInstanceDetails.
        The OCID of dedicated VM host.

        Dedicated VM hosts can be used when launching individual instances from an instance configuration. They
        cannot be used to launch instance pools.


        :param dedicated_vm_host_id: The dedicated_vm_host_id of this InstanceConfigurationLaunchInstanceDetails.
        :type: str
        """
        self._dedicated_vm_host_id = dedicated_vm_host_id

    @property
    def launch_mode(self):
        """
        Gets the launch_mode of this InstanceConfigurationLaunchInstanceDetails.
        Specifies the configuration mode for launching virtual machine (VM) instances. The configuration modes are:
        * `NATIVE` - VM instances launch with iSCSI boot and VFIO devices. The default value for Oracle-provided images.
        * `EMULATED` - VM instances launch with emulated devices, such as the E1000 network driver and emulated SCSI disk controller.
        * `PARAVIRTUALIZED` - VM instances launch with paravirtualized devices using VirtIO drivers.
        * `CUSTOM` - VM instances launch with custom configuration settings specified in the `LaunchOptions` parameter.

        Allowed values for this property are: "NATIVE", "EMULATED", "PARAVIRTUALIZED", "CUSTOM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The launch_mode of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: str
        """
        return self._launch_mode

    @launch_mode.setter
    def launch_mode(self, launch_mode):
        """
        Sets the launch_mode of this InstanceConfigurationLaunchInstanceDetails.
        Specifies the configuration mode for launching virtual machine (VM) instances. The configuration modes are:
        * `NATIVE` - VM instances launch with iSCSI boot and VFIO devices. The default value for Oracle-provided images.
        * `EMULATED` - VM instances launch with emulated devices, such as the E1000 network driver and emulated SCSI disk controller.
        * `PARAVIRTUALIZED` - VM instances launch with paravirtualized devices using VirtIO drivers.
        * `CUSTOM` - VM instances launch with custom configuration settings specified in the `LaunchOptions` parameter.


        :param launch_mode: The launch_mode of this InstanceConfigurationLaunchInstanceDetails.
        :type: str
        """
        allowed_values = ["NATIVE", "EMULATED", "PARAVIRTUALIZED", "CUSTOM"]
        if not value_allowed_none_or_none_sentinel(launch_mode, allowed_values):
            launch_mode = 'UNKNOWN_ENUM_VALUE'
        self._launch_mode = launch_mode

    @property
    def launch_options(self):
        """
        Gets the launch_options of this InstanceConfigurationLaunchInstanceDetails.
        Options for tuning the compatibility and performance of VM shapes. The values that you specify override any default values.


        :return: The launch_options of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: InstanceConfigurationLaunchOptions
        """
        return self._launch_options

    @launch_options.setter
    def launch_options(self, launch_options):
        """
        Sets the launch_options of this InstanceConfigurationLaunchInstanceDetails.
        Options for tuning the compatibility and performance of VM shapes. The values that you specify override any default values.


        :param launch_options: The launch_options of this InstanceConfigurationLaunchInstanceDetails.
        :type: InstanceConfigurationLaunchOptions
        """
        self._launch_options = launch_options

    @property
    def agent_config(self):
        """
        Gets the agent_config of this InstanceConfigurationLaunchInstanceDetails.

        :return: The agent_config of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: InstanceConfigurationLaunchInstanceAgentConfigDetails
        """
        return self._agent_config

    @agent_config.setter
    def agent_config(self, agent_config):
        """
        Sets the agent_config of this InstanceConfigurationLaunchInstanceDetails.

        :param agent_config: The agent_config of this InstanceConfigurationLaunchInstanceDetails.
        :type: InstanceConfigurationLaunchInstanceAgentConfigDetails
        """
        self._agent_config = agent_config

    @property
    def is_pv_encryption_in_transit_enabled(self):
        """
        Gets the is_pv_encryption_in_transit_enabled of this InstanceConfigurationLaunchInstanceDetails.
        Whether to enable in-transit encryption for the data volume's paravirtualized attachment. The default value is false.


        :return: The is_pv_encryption_in_transit_enabled of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: bool
        """
        return self._is_pv_encryption_in_transit_enabled

    @is_pv_encryption_in_transit_enabled.setter
    def is_pv_encryption_in_transit_enabled(self, is_pv_encryption_in_transit_enabled):
        """
        Sets the is_pv_encryption_in_transit_enabled of this InstanceConfigurationLaunchInstanceDetails.
        Whether to enable in-transit encryption for the data volume's paravirtualized attachment. The default value is false.


        :param is_pv_encryption_in_transit_enabled: The is_pv_encryption_in_transit_enabled of this InstanceConfigurationLaunchInstanceDetails.
        :type: bool
        """
        self._is_pv_encryption_in_transit_enabled = is_pv_encryption_in_transit_enabled

    @property
    def preferred_maintenance_action(self):
        """
        Gets the preferred_maintenance_action of this InstanceConfigurationLaunchInstanceDetails.
        The preferred maintenance action for an instance. The default is LIVE_MIGRATE, if live migration is supported.
        * `LIVE_MIGRATE` - Run maintenance using a live migration.
        * `REBOOT` - Run maintenance using a reboot.

        Allowed values for this property are: "LIVE_MIGRATE", "REBOOT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The preferred_maintenance_action of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: str
        """
        return self._preferred_maintenance_action

    @preferred_maintenance_action.setter
    def preferred_maintenance_action(self, preferred_maintenance_action):
        """
        Sets the preferred_maintenance_action of this InstanceConfigurationLaunchInstanceDetails.
        The preferred maintenance action for an instance. The default is LIVE_MIGRATE, if live migration is supported.
        * `LIVE_MIGRATE` - Run maintenance using a live migration.
        * `REBOOT` - Run maintenance using a reboot.


        :param preferred_maintenance_action: The preferred_maintenance_action of this InstanceConfigurationLaunchInstanceDetails.
        :type: str
        """
        allowed_values = ["LIVE_MIGRATE", "REBOOT"]
        if not value_allowed_none_or_none_sentinel(preferred_maintenance_action, allowed_values):
            preferred_maintenance_action = 'UNKNOWN_ENUM_VALUE'
        self._preferred_maintenance_action = preferred_maintenance_action

    @property
    def availability_config(self):
        """
        Gets the availability_config of this InstanceConfigurationLaunchInstanceDetails.
        Options for defining the availabiity of a VM instance after a maintenance event that impacts the underlying hardware.


        :return: The availability_config of this InstanceConfigurationLaunchInstanceDetails.
        :rtype: InstanceConfigurationAvailabilityConfig
        """
        return self._availability_config

    @availability_config.setter
    def availability_config(self, availability_config):
        """
        Sets the availability_config of this InstanceConfigurationLaunchInstanceDetails.
        Options for defining the availabiity of a VM instance after a maintenance event that impacts the underlying hardware.


        :param availability_config: The availability_config of this InstanceConfigurationLaunchInstanceDetails.
        :type: InstanceConfigurationAvailabilityConfig
        """
        self._availability_config = availability_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Stream(object):
    """
    Detailed representation of a stream, including all its partitions.
    """

    #: A constant which can be used with the lifecycle_state property of a Stream.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a Stream.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a Stream.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a Stream.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a Stream.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a Stream.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    def __init__(self, **kwargs):
        """
        Initializes a new Stream object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Stream.
        :type name: str

        :param id:
            The value to assign to the id property of this Stream.
        :type id: str

        :param partitions:
            The value to assign to the partitions property of this Stream.
        :type partitions: int

        :param retention_in_hours:
            The value to assign to the retention_in_hours property of this Stream.
        :type retention_in_hours: int

        :param compartment_id:
            The value to assign to the compartment_id property of this Stream.
        :type compartment_id: str

        :param stream_pool_id:
            The value to assign to the stream_pool_id property of this Stream.
        :type stream_pool_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Stream.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_state_details:
            The value to assign to the lifecycle_state_details property of this Stream.
        :type lifecycle_state_details: str

        :param time_created:
            The value to assign to the time_created property of this Stream.
        :type time_created: datetime

        :param messages_endpoint:
            The value to assign to the messages_endpoint property of this Stream.
        :type messages_endpoint: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Stream.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Stream.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'name': 'str',
            'id': 'str',
            'partitions': 'int',
            'retention_in_hours': 'int',
            'compartment_id': 'str',
            'stream_pool_id': 'str',
            'lifecycle_state': 'str',
            'lifecycle_state_details': 'str',
            'time_created': 'datetime',
            'messages_endpoint': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'name': 'name',
            'id': 'id',
            'partitions': 'partitions',
            'retention_in_hours': 'retentionInHours',
            'compartment_id': 'compartmentId',
            'stream_pool_id': 'streamPoolId',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_state_details': 'lifecycleStateDetails',
            'time_created': 'timeCreated',
            'messages_endpoint': 'messagesEndpoint',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._name = None
        self._id = None
        self._partitions = None
        self._retention_in_hours = None
        self._compartment_id = None
        self._stream_pool_id = None
        self._lifecycle_state = None
        self._lifecycle_state_details = None
        self._time_created = None
        self._messages_endpoint = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Stream.
        The name of the stream. Avoid entering confidential information.

        Example: `TelemetryEvents`


        :return: The name of this Stream.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Stream.
        The name of the stream. Avoid entering confidential information.

        Example: `TelemetryEvents`


        :param name: The name of this Stream.
        :type: str
        """
        self._name = name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Stream.
        The OCID of the stream.


        :return: The id of this Stream.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Stream.
        The OCID of the stream.


        :param id: The id of this Stream.
        :type: str
        """
        self._id = id

    @property
    def partitions(self):
        """
        **[Required]** Gets the partitions of this Stream.
        The number of partitions in the stream.


        :return: The partitions of this Stream.
        :rtype: int
        """
        return self._partitions

    @partitions.setter
    def partitions(self, partitions):
        """
        Sets the partitions of this Stream.
        The number of partitions in the stream.


        :param partitions: The partitions of this Stream.
        :type: int
        """
        self._partitions = partitions

    @property
    def retention_in_hours(self):
        """
        **[Required]** Gets the retention_in_hours of this Stream.
        The retention period of the stream, in hours. This property is read-only.


        :return: The retention_in_hours of this Stream.
        :rtype: int
        """
        return self._retention_in_hours

    @retention_in_hours.setter
    def retention_in_hours(self, retention_in_hours):
        """
        Sets the retention_in_hours of this Stream.
        The retention period of the stream, in hours. This property is read-only.


        :param retention_in_hours: The retention_in_hours of this Stream.
        :type: int
        """
        self._retention_in_hours = retention_in_hours

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Stream.
        The OCID of the stream.


        :return: The compartment_id of this Stream.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Stream.
        The OCID of the stream.


        :param compartment_id: The compartment_id of this Stream.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def stream_pool_id(self):
        """
        **[Required]** Gets the stream_pool_id of this Stream.
        The OCID of the stream pool that contains the stream.


        :return: The stream_pool_id of this Stream.
        :rtype: str
        """
        return self._stream_pool_id

    @stream_pool_id.setter
    def stream_pool_id(self, stream_pool_id):
        """
        Sets the stream_pool_id of this Stream.
        The OCID of the stream pool that contains the stream.


        :param stream_pool_id: The stream_pool_id of this Stream.
        :type: str
        """
        self._stream_pool_id = stream_pool_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Stream.
        The current state of the stream.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "UPDATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Stream.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Stream.
        The current state of the stream.


        :param lifecycle_state: The lifecycle_state of this Stream.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING", "DELETED", "FAILED", "UPDATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_state_details(self):
        """
        Gets the lifecycle_state_details of this Stream.
        Any additional details about the current state of the stream.


        :return: The lifecycle_state_details of this Stream.
        :rtype: str
        """
        return self._lifecycle_state_details

    @lifecycle_state_details.setter
    def lifecycle_state_details(self, lifecycle_state_details):
        """
        Sets the lifecycle_state_details of this Stream.
        Any additional details about the current state of the stream.


        :param lifecycle_state_details: The lifecycle_state_details of this Stream.
        :type: str
        """
        self._lifecycle_state_details = lifecycle_state_details

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this Stream.
        The date and time the stream was created, expressed in in `RFC 3339`__ timestamp format.

        Example: `2018-04-20T00:00:07.405Z`

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_created of this Stream.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this Stream.
        The date and time the stream was created, expressed in in `RFC 3339`__ timestamp format.

        Example: `2018-04-20T00:00:07.405Z`

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_created: The time_created of this Stream.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def messages_endpoint(self):
        """
        **[Required]** Gets the messages_endpoint of this Stream.
        The endpoint to use when creating the StreamClient to consume or publish messages in the stream.
        If the associated stream pool is private, the endpoint is also private and can only be accessed from inside the stream pool's associated subnet.


        :return: The messages_endpoint of this Stream.
        :rtype: str
        """
        return self._messages_endpoint

    @messages_endpoint.setter
    def messages_endpoint(self, messages_endpoint):
        """
        Sets the messages_endpoint of this Stream.
        The endpoint to use when creating the StreamClient to consume or publish messages in the stream.
        If the associated stream pool is private, the endpoint is also private and can only be accessed from inside the stream pool's associated subnet.


        :param messages_endpoint: The messages_endpoint of this Stream.
        :type: str
        """
        self._messages_endpoint = messages_endpoint

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Stream.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. Exists for cross-compatibility only.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Stream.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Stream.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. Exists for cross-compatibility only.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Stream.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Stream.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}'

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Stream.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Stream.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}'

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Stream.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NotificationTopic(object):
    """
    The properties that define a topic. For general information about topics, see
    `Notifications Overview`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Notification/Concepts/notificationoverview.htm
    """

    #: A constant which can be used with the lifecycle_state property of a NotificationTopic.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a NotificationTopic.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a NotificationTopic.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    def __init__(self, **kwargs):
        """
        Initializes a new NotificationTopic object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this NotificationTopic.
        :type name: str

        :param topic_id:
            The value to assign to the topic_id property of this NotificationTopic.
        :type topic_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this NotificationTopic.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this NotificationTopic.
            Allowed values for this property are: "ACTIVE", "DELETING", "CREATING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param description:
            The value to assign to the description property of this NotificationTopic.
        :type description: str

        :param time_created:
            The value to assign to the time_created property of this NotificationTopic.
        :type time_created: datetime

        :param etag:
            The value to assign to the etag property of this NotificationTopic.
        :type etag: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this NotificationTopic.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this NotificationTopic.
        :type defined_tags: dict(str, dict(str, object))

        :param api_endpoint:
            The value to assign to the api_endpoint property of this NotificationTopic.
        :type api_endpoint: str

        """
        self.swagger_types = {
            'name': 'str',
            'topic_id': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'description': 'str',
            'time_created': 'datetime',
            'etag': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'api_endpoint': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'topic_id': 'topicId',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'description': 'description',
            'time_created': 'timeCreated',
            'etag': 'etag',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'api_endpoint': 'apiEndpoint'
        }

        self._name = None
        self._topic_id = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._description = None
        self._time_created = None
        self._etag = None
        self._freeform_tags = None
        self._defined_tags = None
        self._api_endpoint = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this NotificationTopic.
        The name of the topic.


        :return: The name of this NotificationTopic.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this NotificationTopic.
        The name of the topic.


        :param name: The name of this NotificationTopic.
        :type: str
        """
        self._name = name

    @property
    def topic_id(self):
        """
        **[Required]** Gets the topic_id of this NotificationTopic.
        The `OCID`__ of the topic.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The topic_id of this NotificationTopic.
        :rtype: str
        """
        return self._topic_id

    @topic_id.setter
    def topic_id(self, topic_id):
        """
        Sets the topic_id of this NotificationTopic.
        The `OCID`__ of the topic.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param topic_id: The topic_id of this NotificationTopic.
        :type: str
        """
        self._topic_id = topic_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this NotificationTopic.
        The `OCID`__ of the compartment for the topic.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this NotificationTopic.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this NotificationTopic.
        The `OCID`__ of the compartment for the topic.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this NotificationTopic.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this NotificationTopic.
        The lifecycle state of the topic.

        Allowed values for this property are: "ACTIVE", "DELETING", "CREATING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this NotificationTopic.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this NotificationTopic.
        The lifecycle state of the topic.


        :param lifecycle_state: The lifecycle_state of this NotificationTopic.
        :type: str
        """
        allowed_values = ["ACTIVE", "DELETING", "CREATING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def description(self):
        """
        Gets the description of this NotificationTopic.
        The description of the topic.


        :return: The description of this NotificationTopic.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this NotificationTopic.
        The description of the topic.


        :param description: The description of this NotificationTopic.
        :type: str
        """
        self._description = description

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this NotificationTopic.
        The time the topic was created.


        :return: The time_created of this NotificationTopic.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this NotificationTopic.
        The time the topic was created.


        :param time_created: The time_created of this NotificationTopic.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def etag(self):
        """
        Gets the etag of this NotificationTopic.
        For optimistic concurrency control. See `if-match`.


        :return: The etag of this NotificationTopic.
        :rtype: str
        """
        return self._etag

    @etag.setter
    def etag(self, etag):
        """
        Sets the etag of this NotificationTopic.
        For optimistic concurrency control. See `if-match`.


        :param etag: The etag of this NotificationTopic.
        :type: str
        """
        self._etag = etag

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this NotificationTopic.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this NotificationTopic.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this NotificationTopic.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this NotificationTopic.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this NotificationTopic.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this NotificationTopic.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this NotificationTopic.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this NotificationTopic.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def api_endpoint(self):
        """
        **[Required]** Gets the api_endpoint of this NotificationTopic.
        The endpoint for managing subscriptions or publishing messages to the topic.


        :return: The api_endpoint of this NotificationTopic.
        :rtype: str
        """
        return self._api_endpoint

    @api_endpoint.setter
    def api_endpoint(self, api_endpoint):
        """
        Sets the api_endpoint of this NotificationTopic.
        The endpoint for managing subscriptions or publishing messages to the topic.


        :param api_endpoint: The api_endpoint of this NotificationTopic.
        :type: str
        """
        self._api_endpoint = api_endpoint

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class DataFlowClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.data_flow.DataFlowClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new DataFlowClientCompositeOperations object

        :param DataFlowClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def change_private_endpoint_compartment_and_wait_for_state(self, private_endpoint_id, change_private_endpoint_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_flow.DataFlowClient.change_private_endpoint_compartment` and waits for the :py:class:`~oci.data_flow.models.WorkRequest`
        to enter the given state(s).

        :param str private_endpoint_id: (required)
            The unique ID for a private endpoint.

        :param ChangePrivateEndpointCompartmentDetails change_private_endpoint_compartment_details: (required)
            Details for changing a private endpoint's compartment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_flow.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_flow.DataFlowClient.change_private_endpoint_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_private_endpoint_compartment(private_endpoint_id, change_private_endpoint_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_application_and_wait_for_state(self, create_application_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_flow.DataFlowClient.create_application` and waits for the :py:class:`~oci.data_flow.models.Application` acted upon
        to enter the given state(s).

        :param CreateApplicationDetails create_application_details: (required)
            Details to create an application.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_flow.models.Application.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_flow.DataFlowClient.create_application`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_application(create_application_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_application(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_private_endpoint_and_wait_for_state(self, create_private_endpoint_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_flow.DataFlowClient.create_private_endpoint` and waits for the :py:class:`~oci.data_flow.models.WorkRequest`
        to enter the given state(s).

        :param CreatePrivateEndpointDetails create_private_endpoint_details: (required)
            Details to create a private endpoint.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_flow.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_flow.DataFlowClient.create_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_private_endpoint(create_private_endpoint_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_run_and_wait_for_state(self, create_run_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_flow.DataFlowClient.create_run` and waits for the :py:class:`~oci.data_flow.models.Run` acted upon
        to enter the given state(s).

        :param CreateRunDetails create_run_details: (required)
            Details for creating a run of an application.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_flow.models.Run.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_flow.DataFlowClient.create_run`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_run(create_run_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_run(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_application_and_wait_for_state(self, application_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_flow.DataFlowClient.delete_application` and waits for the :py:class:`~oci.data_flow.models.Application` acted upon
        to enter the given state(s).

        :param str application_id: (required)
            The unique ID for an application.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_flow.models.Application.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_flow.DataFlowClient.delete_application`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        initial_get_result = self.client.get_application(application_id)
        operation_result = None
        try:
            operation_result = self.client.delete_application(application_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]

        try:
            waiter_result = oci.wait_until(
                self.client,
                initial_get_result,
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                succeed_on_not_found=True,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_private_endpoint_and_wait_for_state(self, private_endpoint_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_flow.DataFlowClient.delete_private_endpoint` and waits for the :py:class:`~oci.data_flow.models.WorkRequest`
        to enter the given state(s).

        :param str private_endpoint_id: (required)
            The unique ID for a private endpoint.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_flow.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_flow.DataFlowClient.delete_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_private_endpoint(private_endpoint_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_run_and_wait_for_state(self, run_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_flow.DataFlowClient.delete_run` and waits for the :py:class:`~oci.data_flow.models.Run` acted upon
        to enter the given state(s).

        :param str run_id: (required)
            The unique ID for the run

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_flow.models.Run.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_flow.DataFlowClient.delete_run`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        initial_get_result = self.client.get_run(run_id)
        operation_result = None
        try:
            operation_result = self.client.delete_run(run_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]

        try:
            waiter_result = oci.wait_until(
                self.client,
                initial_get_result,
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                succeed_on_not_found=True,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_application_and_wait_for_state(self, update_application_details, application_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_flow.DataFlowClient.update_application` and waits for the :py:class:`~oci.data_flow.models.Application` acted upon
        to enter the given state(s).

        :param UpdateApplicationDetails update_application_details: (required)
            Details for updating an application.

        :param str application_id: (required)
            The unique ID for an application.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_flow.models.Application.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_flow.DataFlowClient.update_application`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_application(update_application_details, application_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_application(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_private_endpoint_and_wait_for_state(self, update_private_endpoint_details, private_endpoint_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_flow.DataFlowClient.update_private_endpoint` and waits for the :py:class:`~oci.data_flow.models.WorkRequest`
        to enter the given state(s).

        :param UpdatePrivateEndpointDetails update_private_endpoint_details: (required)
            Details for updating a private endpoint.

        :param str private_endpoint_id: (required)
            The unique ID for a private endpoint.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_flow.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_flow.DataFlowClient.update_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_private_endpoint(update_private_endpoint_details, private_endpoint_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_run_and_wait_for_state(self, update_run_details, run_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_flow.DataFlowClient.update_run` and waits for the :py:class:`~oci.data_flow.models.Run` acted upon
        to enter the given state(s).

        :param UpdateRunDetails update_run_details: (required)
            Details for updating a run.

        :param str run_id: (required)
            The unique ID for the run

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_flow.models.Run.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_flow.DataFlowClient.update_run`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_run(update_run_details, run_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_run(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_table_compartment_details import ChangeTableCompartmentDetails
from .column import Column
from .create_index_details import CreateIndexDetails
from .create_table_details import CreateTableDetails
from .delete_row_result import DeleteRowResult
from .index import Index
from .index_collection import IndexCollection
from .index_key import IndexKey
from .index_summary import IndexSummary
from .prepared_statement import PreparedStatement
from .query_details import QueryDetails
from .query_result_collection import QueryResultCollection
from .request_usage import RequestUsage
from .row import Row
from .schema import Schema
from .statement_summary import StatementSummary
from .table import Table
from .table_collection import TableCollection
from .table_limits import TableLimits
from .table_summary import TableSummary
from .table_usage_collection import TableUsageCollection
from .table_usage_summary import TableUsageSummary
from .update_row_details import UpdateRowDetails
from .update_row_result import UpdateRowResult
from .update_table_details import UpdateTableDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for nosql services.
nosql_type_mapping = {
    "ChangeTableCompartmentDetails": ChangeTableCompartmentDetails,
    "Column": Column,
    "CreateIndexDetails": CreateIndexDetails,
    "CreateTableDetails": CreateTableDetails,
    "DeleteRowResult": DeleteRowResult,
    "Index": Index,
    "IndexCollection": IndexCollection,
    "IndexKey": IndexKey,
    "IndexSummary": IndexSummary,
    "PreparedStatement": PreparedStatement,
    "QueryDetails": QueryDetails,
    "QueryResultCollection": QueryResultCollection,
    "RequestUsage": RequestUsage,
    "Row": Row,
    "Schema": Schema,
    "StatementSummary": StatementSummary,
    "Table": Table,
    "TableCollection": TableCollection,
    "TableLimits": TableLimits,
    "TableSummary": TableSummary,
    "TableUsageCollection": TableUsageCollection,
    "TableUsageSummary": TableUsageSummary,
    "UpdateRowDetails": UpdateRowDetails,
    "UpdateRowResult": UpdateRowResult,
    "UpdateTableDetails": UpdateTableDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenerateAgentObjectNameDetails(object):
    """
    Generate agent upload name for the given properties
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GenerateAgentObjectNameDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param log_group_id:
            The value to assign to the log_group_id property of this GenerateAgentObjectNameDetails.
        :type log_group_id: str

        :param unique_id:
            The value to assign to the unique_id property of this GenerateAgentObjectNameDetails.
        :type unique_id: str

        :param meta_properties:
            The value to assign to the meta_properties property of this GenerateAgentObjectNameDetails.
        :type meta_properties: str

        :param time_created:
            The value to assign to the time_created property of this GenerateAgentObjectNameDetails.
        :type time_created: datetime

        """
        self.swagger_types = {
            'log_group_id': 'str',
            'unique_id': 'str',
            'meta_properties': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'log_group_id': 'logGroupId',
            'unique_id': 'uniqueId',
            'meta_properties': 'metaProperties',
            'time_created': 'timeCreated'
        }

        self._log_group_id = None
        self._unique_id = None
        self._meta_properties = None
        self._time_created = None

    @property
    def log_group_id(self):
        """
        **[Required]** Gets the log_group_id of this GenerateAgentObjectNameDetails.
        Log group OCID


        :return: The log_group_id of this GenerateAgentObjectNameDetails.
        :rtype: str
        """
        return self._log_group_id

    @log_group_id.setter
    def log_group_id(self, log_group_id):
        """
        Sets the log_group_id of this GenerateAgentObjectNameDetails.
        Log group OCID


        :param log_group_id: The log_group_id of this GenerateAgentObjectNameDetails.
        :type: str
        """
        self._log_group_id = log_group_id

    @property
    def unique_id(self):
        """
        **[Required]** Gets the unique_id of this GenerateAgentObjectNameDetails.
        Internal identifier used to uniquely identify the agent upload request


        :return: The unique_id of this GenerateAgentObjectNameDetails.
        :rtype: str
        """
        return self._unique_id

    @unique_id.setter
    def unique_id(self, unique_id):
        """
        Sets the unique_id of this GenerateAgentObjectNameDetails.
        Internal identifier used to uniquely identify the agent upload request


        :param unique_id: The unique_id of this GenerateAgentObjectNameDetails.
        :type: str
        """
        self._unique_id = unique_id

    @property
    def meta_properties(self):
        """
        **[Required]** Gets the meta_properties of this GenerateAgentObjectNameDetails.
        Metadata associated with the upload used during processing


        :return: The meta_properties of this GenerateAgentObjectNameDetails.
        :rtype: str
        """
        return self._meta_properties

    @meta_properties.setter
    def meta_properties(self, meta_properties):
        """
        Sets the meta_properties of this GenerateAgentObjectNameDetails.
        Metadata associated with the upload used during processing


        :param meta_properties: The meta_properties of this GenerateAgentObjectNameDetails.
        :type: str
        """
        self._meta_properties = meta_properties

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this GenerateAgentObjectNameDetails.
        The time when this upload is created. An RFC3339 formatted datetime string


        :return: The time_created of this GenerateAgentObjectNameDetails.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this GenerateAgentObjectNameDetails.
        The time when this upload is created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this GenerateAgentObjectNameDetails.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PatchSummary(object):
    """
    A Patch for a DB system or DB Home.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator. If you're an administrator who needs to write policies to give users access,
    see `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the last_action property of a PatchSummary.
    #: This constant has a value of "APPLY"
    LAST_ACTION_APPLY = "APPLY"

    #: A constant which can be used with the last_action property of a PatchSummary.
    #: This constant has a value of "PRECHECK"
    LAST_ACTION_PRECHECK = "PRECHECK"

    #: A constant which can be used with the available_actions property of a PatchSummary.
    #: This constant has a value of "APPLY"
    AVAILABLE_ACTIONS_APPLY = "APPLY"

    #: A constant which can be used with the available_actions property of a PatchSummary.
    #: This constant has a value of "PRECHECK"
    AVAILABLE_ACTIONS_PRECHECK = "PRECHECK"

    #: A constant which can be used with the lifecycle_state property of a PatchSummary.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a PatchSummary.
    #: This constant has a value of "SUCCESS"
    LIFECYCLE_STATE_SUCCESS = "SUCCESS"

    #: A constant which can be used with the lifecycle_state property of a PatchSummary.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a PatchSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new PatchSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this PatchSummary.
        :type id: str

        :param description:
            The value to assign to the description property of this PatchSummary.
        :type description: str

        :param last_action:
            The value to assign to the last_action property of this PatchSummary.
            Allowed values for this property are: "APPLY", "PRECHECK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type last_action: str

        :param available_actions:
            The value to assign to the available_actions property of this PatchSummary.
            Allowed values for items in this list are: "APPLY", "PRECHECK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type available_actions: list[str]

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this PatchSummary.
        :type lifecycle_details: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this PatchSummary.
            Allowed values for this property are: "AVAILABLE", "SUCCESS", "IN_PROGRESS", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_released:
            The value to assign to the time_released property of this PatchSummary.
        :type time_released: datetime

        :param version:
            The value to assign to the version property of this PatchSummary.
        :type version: str

        """
        self.swagger_types = {
            'id': 'str',
            'description': 'str',
            'last_action': 'str',
            'available_actions': 'list[str]',
            'lifecycle_details': 'str',
            'lifecycle_state': 'str',
            'time_released': 'datetime',
            'version': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'description': 'description',
            'last_action': 'lastAction',
            'available_actions': 'availableActions',
            'lifecycle_details': 'lifecycleDetails',
            'lifecycle_state': 'lifecycleState',
            'time_released': 'timeReleased',
            'version': 'version'
        }

        self._id = None
        self._description = None
        self._last_action = None
        self._available_actions = None
        self._lifecycle_details = None
        self._lifecycle_state = None
        self._time_released = None
        self._version = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this PatchSummary.
        The `OCID`__ of the patch.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this PatchSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PatchSummary.
        The `OCID`__ of the patch.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this PatchSummary.
        :type: str
        """
        self._id = id

    @property
    def description(self):
        """
        **[Required]** Gets the description of this PatchSummary.
        The text describing this patch package.


        :return: The description of this PatchSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this PatchSummary.
        The text describing this patch package.


        :param description: The description of this PatchSummary.
        :type: str
        """
        self._description = description

    @property
    def last_action(self):
        """
        Gets the last_action of this PatchSummary.
        Action that is currently being performed or was completed last.

        Allowed values for this property are: "APPLY", "PRECHECK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The last_action of this PatchSummary.
        :rtype: str
        """
        return self._last_action

    @last_action.setter
    def last_action(self, last_action):
        """
        Sets the last_action of this PatchSummary.
        Action that is currently being performed or was completed last.


        :param last_action: The last_action of this PatchSummary.
        :type: str
        """
        allowed_values = ["APPLY", "PRECHECK"]
        if not value_allowed_none_or_none_sentinel(last_action, allowed_values):
            last_action = 'UNKNOWN_ENUM_VALUE'
        self._last_action = last_action

    @property
    def available_actions(self):
        """
        Gets the available_actions of this PatchSummary.
        Actions that can possibly be performed using this patch.

        Allowed values for items in this list are: "APPLY", "PRECHECK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The available_actions of this PatchSummary.
        :rtype: list[str]
        """
        return self._available_actions

    @available_actions.setter
    def available_actions(self, available_actions):
        """
        Sets the available_actions of this PatchSummary.
        Actions that can possibly be performed using this patch.


        :param available_actions: The available_actions of this PatchSummary.
        :type: list[str]
        """
        allowed_values = ["APPLY", "PRECHECK"]
        if available_actions:
            available_actions[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in available_actions]
        self._available_actions = available_actions

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this PatchSummary.
        A descriptive text associated with the lifecycleState.
        Typically can contain additional displayable text.


        :return: The lifecycle_details of this PatchSummary.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this PatchSummary.
        A descriptive text associated with the lifecycleState.
        Typically can contain additional displayable text.


        :param lifecycle_details: The lifecycle_details of this PatchSummary.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this PatchSummary.
        The current state of the patch as a result of lastAction.

        Allowed values for this property are: "AVAILABLE", "SUCCESS", "IN_PROGRESS", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this PatchSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this PatchSummary.
        The current state of the patch as a result of lastAction.


        :param lifecycle_state: The lifecycle_state of this PatchSummary.
        :type: str
        """
        allowed_values = ["AVAILABLE", "SUCCESS", "IN_PROGRESS", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def time_released(self):
        """
        **[Required]** Gets the time_released of this PatchSummary.
        The date and time that the patch was released.


        :return: The time_released of this PatchSummary.
        :rtype: datetime
        """
        return self._time_released

    @time_released.setter
    def time_released(self, time_released):
        """
        Sets the time_released of this PatchSummary.
        The date and time that the patch was released.


        :param time_released: The time_released of this PatchSummary.
        :type: datetime
        """
        self._time_released = time_released

    @property
    def version(self):
        """
        **[Required]** Gets the version of this PatchSummary.
        The version of this patch package.


        :return: The version of this PatchSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this PatchSummary.
        The version of this patch package.


        :param version: The version of this PatchSummary.
        :type: str
        """
        self._version = version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsSourceExtendedFieldDefinition(object):
    """
    LogAnalyticsSourceExtendedFieldDefinition
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsSourceExtendedFieldDefinition object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param field:
            The value to assign to the field property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type field: LogAnalyticsField

        :param display_regular_expression:
            The value to assign to the display_regular_expression property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type display_regular_expression: str

        :param extended_fields:
            The value to assign to the extended_fields property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type extended_fields: list[LogAnalyticsExtendedField]

        :param base_field_name:
            The value to assign to the base_field_name property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type base_field_name: str

        :param base_field_log_text:
            The value to assign to the base_field_log_text property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type base_field_log_text: str

        :param condition_data_type:
            The value to assign to the condition_data_type property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type condition_data_type: str

        :param condition_field:
            The value to assign to the condition_field property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type condition_field: str

        :param condition_operator:
            The value to assign to the condition_operator property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type condition_operator: str

        :param condition_value:
            The value to assign to the condition_value property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type condition_value: str

        :param converted_regular_expression:
            The value to assign to the converted_regular_expression property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type converted_regular_expression: str

        :param is_enabled:
            The value to assign to the is_enabled property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type is_enabled: bool

        :param extended_field_definition_id:
            The value to assign to the extended_field_definition_id property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type extended_field_definition_id: int

        :param is_system:
            The value to assign to the is_system property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type is_system: bool

        :param regular_expression:
            The value to assign to the regular_expression property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type regular_expression: str

        :param source_id:
            The value to assign to the source_id property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type source_id: int

        :param time_updated:
            The value to assign to the time_updated property of this LogAnalyticsSourceExtendedFieldDefinition.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'field': 'LogAnalyticsField',
            'display_regular_expression': 'str',
            'extended_fields': 'list[LogAnalyticsExtendedField]',
            'base_field_name': 'str',
            'base_field_log_text': 'str',
            'condition_data_type': 'str',
            'condition_field': 'str',
            'condition_operator': 'str',
            'condition_value': 'str',
            'converted_regular_expression': 'str',
            'is_enabled': 'bool',
            'extended_field_definition_id': 'int',
            'is_system': 'bool',
            'regular_expression': 'str',
            'source_id': 'int',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'field': 'field',
            'display_regular_expression': 'displayRegularExpression',
            'extended_fields': 'extendedFields',
            'base_field_name': 'baseFieldName',
            'base_field_log_text': 'baseFieldLogText',
            'condition_data_type': 'conditionDataType',
            'condition_field': 'conditionField',
            'condition_operator': 'conditionOperator',
            'condition_value': 'conditionValue',
            'converted_regular_expression': 'convertedRegularExpression',
            'is_enabled': 'isEnabled',
            'extended_field_definition_id': 'extendedFieldDefinitionId',
            'is_system': 'isSystem',
            'regular_expression': 'regularExpression',
            'source_id': 'sourceId',
            'time_updated': 'timeUpdated'
        }

        self._field = None
        self._display_regular_expression = None
        self._extended_fields = None
        self._base_field_name = None
        self._base_field_log_text = None
        self._condition_data_type = None
        self._condition_field = None
        self._condition_operator = None
        self._condition_value = None
        self._converted_regular_expression = None
        self._is_enabled = None
        self._extended_field_definition_id = None
        self._is_system = None
        self._regular_expression = None
        self._source_id = None
        self._time_updated = None

    @property
    def field(self):
        """
        Gets the field of this LogAnalyticsSourceExtendedFieldDefinition.

        :return: The field of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: LogAnalyticsField
        """
        return self._field

    @field.setter
    def field(self, field):
        """
        Sets the field of this LogAnalyticsSourceExtendedFieldDefinition.

        :param field: The field of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: LogAnalyticsField
        """
        self._field = field

    @property
    def display_regular_expression(self):
        """
        Gets the display_regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        display regular expression


        :return: The display_regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: str
        """
        return self._display_regular_expression

    @display_regular_expression.setter
    def display_regular_expression(self, display_regular_expression):
        """
        Sets the display_regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        display regular expression


        :param display_regular_expression: The display_regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: str
        """
        self._display_regular_expression = display_regular_expression

    @property
    def extended_fields(self):
        """
        Gets the extended_fields of this LogAnalyticsSourceExtendedFieldDefinition.
        extended fields


        :return: The extended_fields of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: list[LogAnalyticsExtendedField]
        """
        return self._extended_fields

    @extended_fields.setter
    def extended_fields(self, extended_fields):
        """
        Sets the extended_fields of this LogAnalyticsSourceExtendedFieldDefinition.
        extended fields


        :param extended_fields: The extended_fields of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: list[LogAnalyticsExtendedField]
        """
        self._extended_fields = extended_fields

    @property
    def base_field_name(self):
        """
        Gets the base_field_name of this LogAnalyticsSourceExtendedFieldDefinition.
        base field internal name


        :return: The base_field_name of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: str
        """
        return self._base_field_name

    @base_field_name.setter
    def base_field_name(self, base_field_name):
        """
        Sets the base_field_name of this LogAnalyticsSourceExtendedFieldDefinition.
        base field internal name


        :param base_field_name: The base_field_name of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: str
        """
        self._base_field_name = base_field_name

    @property
    def base_field_log_text(self):
        """
        Gets the base_field_log_text of this LogAnalyticsSourceExtendedFieldDefinition.
        base field log text


        :return: The base_field_log_text of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: str
        """
        return self._base_field_log_text

    @base_field_log_text.setter
    def base_field_log_text(self, base_field_log_text):
        """
        Sets the base_field_log_text of this LogAnalyticsSourceExtendedFieldDefinition.
        base field log text


        :param base_field_log_text: The base_field_log_text of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: str
        """
        self._base_field_log_text = base_field_log_text

    @property
    def condition_data_type(self):
        """
        Gets the condition_data_type of this LogAnalyticsSourceExtendedFieldDefinition.
        conditional data type


        :return: The condition_data_type of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: str
        """
        return self._condition_data_type

    @condition_data_type.setter
    def condition_data_type(self, condition_data_type):
        """
        Sets the condition_data_type of this LogAnalyticsSourceExtendedFieldDefinition.
        conditional data type


        :param condition_data_type: The condition_data_type of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: str
        """
        self._condition_data_type = condition_data_type

    @property
    def condition_field(self):
        """
        Gets the condition_field of this LogAnalyticsSourceExtendedFieldDefinition.
        conditional field


        :return: The condition_field of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: str
        """
        return self._condition_field

    @condition_field.setter
    def condition_field(self, condition_field):
        """
        Sets the condition_field of this LogAnalyticsSourceExtendedFieldDefinition.
        conditional field


        :param condition_field: The condition_field of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: str
        """
        self._condition_field = condition_field

    @property
    def condition_operator(self):
        """
        Gets the condition_operator of this LogAnalyticsSourceExtendedFieldDefinition.
        conditional operator


        :return: The condition_operator of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: str
        """
        return self._condition_operator

    @condition_operator.setter
    def condition_operator(self, condition_operator):
        """
        Sets the condition_operator of this LogAnalyticsSourceExtendedFieldDefinition.
        conditional operator


        :param condition_operator: The condition_operator of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: str
        """
        self._condition_operator = condition_operator

    @property
    def condition_value(self):
        """
        Gets the condition_value of this LogAnalyticsSourceExtendedFieldDefinition.
        conditional value


        :return: The condition_value of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: str
        """
        return self._condition_value

    @condition_value.setter
    def condition_value(self, condition_value):
        """
        Sets the condition_value of this LogAnalyticsSourceExtendedFieldDefinition.
        conditional value


        :param condition_value: The condition_value of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: str
        """
        self._condition_value = condition_value

    @property
    def converted_regular_expression(self):
        """
        Gets the converted_regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        converted regular expression


        :return: The converted_regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: str
        """
        return self._converted_regular_expression

    @converted_regular_expression.setter
    def converted_regular_expression(self, converted_regular_expression):
        """
        Sets the converted_regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        converted regular expression


        :param converted_regular_expression: The converted_regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: str
        """
        self._converted_regular_expression = converted_regular_expression

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this LogAnalyticsSourceExtendedFieldDefinition.
        enabled


        :return: The is_enabled of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this LogAnalyticsSourceExtendedFieldDefinition.
        enabled


        :param is_enabled: The is_enabled of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def extended_field_definition_id(self):
        """
        Gets the extended_field_definition_id of this LogAnalyticsSourceExtendedFieldDefinition.
        id


        :return: The extended_field_definition_id of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: int
        """
        return self._extended_field_definition_id

    @extended_field_definition_id.setter
    def extended_field_definition_id(self, extended_field_definition_id):
        """
        Sets the extended_field_definition_id of this LogAnalyticsSourceExtendedFieldDefinition.
        id


        :param extended_field_definition_id: The extended_field_definition_id of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: int
        """
        self._extended_field_definition_id = extended_field_definition_id

    @property
    def is_system(self):
        """
        Gets the is_system of this LogAnalyticsSourceExtendedFieldDefinition.
        is system flag


        :return: The is_system of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: bool
        """
        return self._is_system

    @is_system.setter
    def is_system(self, is_system):
        """
        Sets the is_system of this LogAnalyticsSourceExtendedFieldDefinition.
        is system flag


        :param is_system: The is_system of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: bool
        """
        self._is_system = is_system

    @property
    def regular_expression(self):
        """
        Gets the regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        regular expression


        :return: The regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: str
        """
        return self._regular_expression

    @regular_expression.setter
    def regular_expression(self, regular_expression):
        """
        Sets the regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        regular expression


        :param regular_expression: The regular_expression of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: str
        """
        self._regular_expression = regular_expression

    @property
    def source_id(self):
        """
        Gets the source_id of this LogAnalyticsSourceExtendedFieldDefinition.
        source Id


        :return: The source_id of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: int
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """
        Sets the source_id of this LogAnalyticsSourceExtendedFieldDefinition.
        source Id


        :param source_id: The source_id of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: int
        """
        self._source_id = source_id

    @property
    def time_updated(self):
        """
        Gets the time_updated of this LogAnalyticsSourceExtendedFieldDefinition.
        last updated date


        :return: The time_updated of this LogAnalyticsSourceExtendedFieldDefinition.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this LogAnalyticsSourceExtendedFieldDefinition.
        last updated date


        :param time_updated: The time_updated of this LogAnalyticsSourceExtendedFieldDefinition.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TableUsageSummary(object):
    """
    TableUsageSummary represents a single usage record, or slice, that includes
    information about read and write throughput consumed during that period
    as well as the current information regarding storage capacity. In
    addition the count of throttling exceptions for the period is reported.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TableUsageSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param seconds_in_period:
            The value to assign to the seconds_in_period property of this TableUsageSummary.
        :type seconds_in_period: int

        :param read_units:
            The value to assign to the read_units property of this TableUsageSummary.
        :type read_units: int

        :param write_units:
            The value to assign to the write_units property of this TableUsageSummary.
        :type write_units: int

        :param storage_in_g_bs:
            The value to assign to the storage_in_g_bs property of this TableUsageSummary.
        :type storage_in_g_bs: int

        :param read_throttle_count:
            The value to assign to the read_throttle_count property of this TableUsageSummary.
        :type read_throttle_count: int

        :param write_throttle_count:
            The value to assign to the write_throttle_count property of this TableUsageSummary.
        :type write_throttle_count: int

        :param storage_throttle_count:
            The value to assign to the storage_throttle_count property of this TableUsageSummary.
        :type storage_throttle_count: int

        """
        self.swagger_types = {
            'seconds_in_period': 'int',
            'read_units': 'int',
            'write_units': 'int',
            'storage_in_g_bs': 'int',
            'read_throttle_count': 'int',
            'write_throttle_count': 'int',
            'storage_throttle_count': 'int'
        }

        self.attribute_map = {
            'seconds_in_period': 'secondsInPeriod',
            'read_units': 'readUnits',
            'write_units': 'writeUnits',
            'storage_in_g_bs': 'storageInGBs',
            'read_throttle_count': 'readThrottleCount',
            'write_throttle_count': 'writeThrottleCount',
            'storage_throttle_count': 'storageThrottleCount'
        }

        self._seconds_in_period = None
        self._read_units = None
        self._write_units = None
        self._storage_in_g_bs = None
        self._read_throttle_count = None
        self._write_throttle_count = None
        self._storage_throttle_count = None

    @property
    def seconds_in_period(self):
        """
        Gets the seconds_in_period of this TableUsageSummary.
        The length of the sampling period.


        :return: The seconds_in_period of this TableUsageSummary.
        :rtype: int
        """
        return self._seconds_in_period

    @seconds_in_period.setter
    def seconds_in_period(self, seconds_in_period):
        """
        Sets the seconds_in_period of this TableUsageSummary.
        The length of the sampling period.


        :param seconds_in_period: The seconds_in_period of this TableUsageSummary.
        :type: int
        """
        self._seconds_in_period = seconds_in_period

    @property
    def read_units(self):
        """
        Gets the read_units of this TableUsageSummary.
        Read throughput during the sampling period.


        :return: The read_units of this TableUsageSummary.
        :rtype: int
        """
        return self._read_units

    @read_units.setter
    def read_units(self, read_units):
        """
        Sets the read_units of this TableUsageSummary.
        Read throughput during the sampling period.


        :param read_units: The read_units of this TableUsageSummary.
        :type: int
        """
        self._read_units = read_units

    @property
    def write_units(self):
        """
        Gets the write_units of this TableUsageSummary.
        Write throughput during the sampling period.


        :return: The write_units of this TableUsageSummary.
        :rtype: int
        """
        return self._write_units

    @write_units.setter
    def write_units(self, write_units):
        """
        Sets the write_units of this TableUsageSummary.
        Write throughput during the sampling period.


        :param write_units: The write_units of this TableUsageSummary.
        :type: int
        """
        self._write_units = write_units

    @property
    def storage_in_g_bs(self):
        """
        Gets the storage_in_g_bs of this TableUsageSummary.
        The size of the table, in GB.


        :return: The storage_in_g_bs of this TableUsageSummary.
        :rtype: int
        """
        return self._storage_in_g_bs

    @storage_in_g_bs.setter
    def storage_in_g_bs(self, storage_in_g_bs):
        """
        Sets the storage_in_g_bs of this TableUsageSummary.
        The size of the table, in GB.


        :param storage_in_g_bs: The storage_in_g_bs of this TableUsageSummary.
        :type: int
        """
        self._storage_in_g_bs = storage_in_g_bs

    @property
    def read_throttle_count(self):
        """
        Gets the read_throttle_count of this TableUsageSummary.
        The number of times reads were throttled due to exceeding
        the read throughput limit.


        :return: The read_throttle_count of this TableUsageSummary.
        :rtype: int
        """
        return self._read_throttle_count

    @read_throttle_count.setter
    def read_throttle_count(self, read_throttle_count):
        """
        Sets the read_throttle_count of this TableUsageSummary.
        The number of times reads were throttled due to exceeding
        the read throughput limit.


        :param read_throttle_count: The read_throttle_count of this TableUsageSummary.
        :type: int
        """
        self._read_throttle_count = read_throttle_count

    @property
    def write_throttle_count(self):
        """
        Gets the write_throttle_count of this TableUsageSummary.
        The number of times writes were throttled due to exceeding
        the write throughput limit.


        :return: The write_throttle_count of this TableUsageSummary.
        :rtype: int
        """
        return self._write_throttle_count

    @write_throttle_count.setter
    def write_throttle_count(self, write_throttle_count):
        """
        Sets the write_throttle_count of this TableUsageSummary.
        The number of times writes were throttled due to exceeding
        the write throughput limit.


        :param write_throttle_count: The write_throttle_count of this TableUsageSummary.
        :type: int
        """
        self._write_throttle_count = write_throttle_count

    @property
    def storage_throttle_count(self):
        """
        Gets the storage_throttle_count of this TableUsageSummary.
        The number of times writes were throttled because the table
        exceeded its size limit.


        :return: The storage_throttle_count of this TableUsageSummary.
        :rtype: int
        """
        return self._storage_throttle_count

    @storage_throttle_count.setter
    def storage_throttle_count(self, storage_throttle_count):
        """
        Sets the storage_throttle_count of this TableUsageSummary.
        The number of times writes were throttled because the table
        exceeded its size limit.


        :param storage_throttle_count: The storage_throttle_count of this TableUsageSummary.
        :type: int
        """
        self._storage_throttle_count = storage_throttle_count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AddBlockStorageDetails(object):
    """
    The information about additionally added block volumes
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AddBlockStorageDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cluster_admin_password:
            The value to assign to the cluster_admin_password property of this AddBlockStorageDetails.
        :type cluster_admin_password: str

        :param block_volume_size_in_gbs:
            The value to assign to the block_volume_size_in_gbs property of this AddBlockStorageDetails.
        :type block_volume_size_in_gbs: int

        """
        self.swagger_types = {
            'cluster_admin_password': 'str',
            'block_volume_size_in_gbs': 'int'
        }

        self.attribute_map = {
            'cluster_admin_password': 'clusterAdminPassword',
            'block_volume_size_in_gbs': 'blockVolumeSizeInGBs'
        }

        self._cluster_admin_password = None
        self._block_volume_size_in_gbs = None

    @property
    def cluster_admin_password(self):
        """
        **[Required]** Gets the cluster_admin_password of this AddBlockStorageDetails.
        Base-64 encoded password for Cloudera Manager admin user


        :return: The cluster_admin_password of this AddBlockStorageDetails.
        :rtype: str
        """
        return self._cluster_admin_password

    @cluster_admin_password.setter
    def cluster_admin_password(self, cluster_admin_password):
        """
        Sets the cluster_admin_password of this AddBlockStorageDetails.
        Base-64 encoded password for Cloudera Manager admin user


        :param cluster_admin_password: The cluster_admin_password of this AddBlockStorageDetails.
        :type: str
        """
        self._cluster_admin_password = cluster_admin_password

    @property
    def block_volume_size_in_gbs(self):
        """
        **[Required]** Gets the block_volume_size_in_gbs of this AddBlockStorageDetails.
        The size of block volume in GB that needs to be added to each worker node.
        All the necessary details needed for attachment are managed by service itself.


        :return: The block_volume_size_in_gbs of this AddBlockStorageDetails.
        :rtype: int
        """
        return self._block_volume_size_in_gbs

    @block_volume_size_in_gbs.setter
    def block_volume_size_in_gbs(self, block_volume_size_in_gbs):
        """
        Sets the block_volume_size_in_gbs of this AddBlockStorageDetails.
        The size of block volume in GB that needs to be added to each worker node.
        All the necessary details needed for attachment are managed by service itself.


        :param block_volume_size_in_gbs: The block_volume_size_in_gbs of this AddBlockStorageDetails.
        :type: int
        """
        self._block_volume_size_in_gbs = block_volume_size_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SoftwareSourceSummary(object):
    """
    A software source contains a collection of packages
    """

    #: A constant which can be used with the status property of a SoftwareSourceSummary.
    #: This constant has a value of "NORMAL"
    STATUS_NORMAL = "NORMAL"

    #: A constant which can be used with the status property of a SoftwareSourceSummary.
    #: This constant has a value of "UNREACHABLE"
    STATUS_UNREACHABLE = "UNREACHABLE"

    #: A constant which can be used with the status property of a SoftwareSourceSummary.
    #: This constant has a value of "ERROR"
    STATUS_ERROR = "ERROR"

    #: A constant which can be used with the status property of a SoftwareSourceSummary.
    #: This constant has a value of "WARNING"
    STATUS_WARNING = "WARNING"

    #: A constant which can be used with the lifecycle_state property of a SoftwareSourceSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a SoftwareSourceSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a SoftwareSourceSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SoftwareSourceSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a SoftwareSourceSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a SoftwareSourceSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new SoftwareSourceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SoftwareSourceSummary.
        :type id: str

        :param description:
            The value to assign to the description property of this SoftwareSourceSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this SoftwareSourceSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this SoftwareSourceSummary.
        :type display_name: str

        :param repo_type:
            The value to assign to the repo_type property of this SoftwareSourceSummary.
        :type repo_type: str

        :param status:
            The value to assign to the status property of this SoftwareSourceSummary.
            Allowed values for this property are: "NORMAL", "UNREACHABLE", "ERROR", "WARNING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param packages:
            The value to assign to the packages property of this SoftwareSourceSummary.
        :type packages: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SoftwareSourceSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param parent_id:
            The value to assign to the parent_id property of this SoftwareSourceSummary.
        :type parent_id: str

        :param parent_name:
            The value to assign to the parent_name property of this SoftwareSourceSummary.
        :type parent_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this SoftwareSourceSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this SoftwareSourceSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'display_name': 'str',
            'repo_type': 'str',
            'status': 'str',
            'packages': 'int',
            'lifecycle_state': 'str',
            'parent_id': 'str',
            'parent_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'repo_type': 'repoType',
            'status': 'status',
            'packages': 'packages',
            'lifecycle_state': 'lifecycleState',
            'parent_id': 'parentId',
            'parent_name': 'parentName',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._description = None
        self._compartment_id = None
        self._display_name = None
        self._repo_type = None
        self._status = None
        self._packages = None
        self._lifecycle_state = None
        self._parent_id = None
        self._parent_name = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SoftwareSourceSummary.
        OCID for the Software Source


        :return: The id of this SoftwareSourceSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SoftwareSourceSummary.
        OCID for the Software Source


        :param id: The id of this SoftwareSourceSummary.
        :type: str
        """
        self._id = id

    @property
    def description(self):
        """
        Gets the description of this SoftwareSourceSummary.
        Information specified by the user about the software source


        :return: The description of this SoftwareSourceSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SoftwareSourceSummary.
        Information specified by the user about the software source


        :param description: The description of this SoftwareSourceSummary.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this SoftwareSourceSummary.
        OCID for the Compartment


        :return: The compartment_id of this SoftwareSourceSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this SoftwareSourceSummary.
        OCID for the Compartment


        :param compartment_id: The compartment_id of this SoftwareSourceSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this SoftwareSourceSummary.
        User friendly name for the software source


        :return: The display_name of this SoftwareSourceSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this SoftwareSourceSummary.
        User friendly name for the software source


        :param display_name: The display_name of this SoftwareSourceSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def repo_type(self):
        """
        **[Required]** Gets the repo_type of this SoftwareSourceSummary.
        Type of the Software Source


        :return: The repo_type of this SoftwareSourceSummary.
        :rtype: str
        """
        return self._repo_type

    @repo_type.setter
    def repo_type(self, repo_type):
        """
        Sets the repo_type of this SoftwareSourceSummary.
        Type of the Software Source


        :param repo_type: The repo_type of this SoftwareSourceSummary.
        :type: str
        """
        self._repo_type = repo_type

    @property
    def status(self):
        """
        Gets the status of this SoftwareSourceSummary.
        status of the software source.

        Allowed values for this property are: "NORMAL", "UNREACHABLE", "ERROR", "WARNING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this SoftwareSourceSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this SoftwareSourceSummary.
        status of the software source.


        :param status: The status of this SoftwareSourceSummary.
        :type: str
        """
        allowed_values = ["NORMAL", "UNREACHABLE", "ERROR", "WARNING"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def packages(self):
        """
        Gets the packages of this SoftwareSourceSummary.
        Number of packages


        :return: The packages of this SoftwareSourceSummary.
        :rtype: int
        """
        return self._packages

    @packages.setter
    def packages(self, packages):
        """
        Sets the packages of this SoftwareSourceSummary.
        Number of packages


        :param packages: The packages of this SoftwareSourceSummary.
        :type: int
        """
        self._packages = packages

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this SoftwareSourceSummary.
        The current state of the software source.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SoftwareSourceSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SoftwareSourceSummary.
        The current state of the software source.


        :param lifecycle_state: The lifecycle_state of this SoftwareSourceSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def parent_id(self):
        """
        Gets the parent_id of this SoftwareSourceSummary.
        OCID for the parent software source, if there is one


        :return: The parent_id of this SoftwareSourceSummary.
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """
        Sets the parent_id of this SoftwareSourceSummary.
        OCID for the parent software source, if there is one


        :param parent_id: The parent_id of this SoftwareSourceSummary.
        :type: str
        """
        self._parent_id = parent_id

    @property
    def parent_name(self):
        """
        Gets the parent_name of this SoftwareSourceSummary.
        Display name the parent software source, if there is one


        :return: The parent_name of this SoftwareSourceSummary.
        :rtype: str
        """
        return self._parent_name

    @parent_name.setter
    def parent_name(self, parent_name):
        """
        Sets the parent_name of this SoftwareSourceSummary.
        Display name the parent software source, if there is one


        :param parent_name: The parent_name of this SoftwareSourceSummary.
        :type: str
        """
        self._parent_name = parent_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this SoftwareSourceSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this SoftwareSourceSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this SoftwareSourceSummary.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this SoftwareSourceSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this SoftwareSourceSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this SoftwareSourceSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this SoftwareSourceSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this SoftwareSourceSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from oci.encryption.algorithms import Algorithm

import math

DEFAULT_ENCODING = "utf-8"

DEFAULT_ALGORITHM = Algorithm.AES_256_GCM_IV12_TAG16

DEFAULT_MAX_GCM_ENCRYPTION_SIZE = int(math.pow(2, 31) - 1)

DEFAULT_MAX_ENCRYPTION_SIZE_SENTINEL = object()



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SoftwarePackageSummary(object):
    """
    Summary information for a software package
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SoftwarePackageSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this SoftwarePackageSummary.
        :type display_name: str

        :param name:
            The value to assign to the name property of this SoftwarePackageSummary.
        :type name: str

        :param type:
            The value to assign to the type property of this SoftwarePackageSummary.
        :type type: str

        :param version:
            The value to assign to the version property of this SoftwarePackageSummary.
        :type version: str

        :param architecture:
            The value to assign to the architecture property of this SoftwarePackageSummary.
        :type architecture: str

        :param checksum:
            The value to assign to the checksum property of this SoftwarePackageSummary.
        :type checksum: str

        :param checksum_type:
            The value to assign to the checksum_type property of this SoftwarePackageSummary.
        :type checksum_type: str

        """
        self.swagger_types = {
            'display_name': 'str',
            'name': 'str',
            'type': 'str',
            'version': 'str',
            'architecture': 'str',
            'checksum': 'str',
            'checksum_type': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'name': 'name',
            'type': 'type',
            'version': 'version',
            'architecture': 'architecture',
            'checksum': 'checksum',
            'checksum_type': 'checksumType'
        }

        self._display_name = None
        self._name = None
        self._type = None
        self._version = None
        self._architecture = None
        self._checksum = None
        self._checksum_type = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this SoftwarePackageSummary.
        Package name


        :return: The display_name of this SoftwarePackageSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this SoftwarePackageSummary.
        Package name


        :param display_name: The display_name of this SoftwarePackageSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def name(self):
        """
        **[Required]** Gets the name of this SoftwarePackageSummary.
        Unique identifier for the package. NOTE - This is not an OCID


        :return: The name of this SoftwarePackageSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SoftwarePackageSummary.
        Unique identifier for the package. NOTE - This is not an OCID


        :param name: The name of this SoftwarePackageSummary.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        **[Required]** Gets the type of this SoftwarePackageSummary.
        Type of the package


        :return: The type of this SoftwarePackageSummary.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SoftwarePackageSummary.
        Type of the package


        :param type: The type of this SoftwarePackageSummary.
        :type: str
        """
        self._type = type

    @property
    def version(self):
        """
        **[Required]** Gets the version of this SoftwarePackageSummary.
        Version of the package


        :return: The version of this SoftwarePackageSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this SoftwarePackageSummary.
        Version of the package


        :param version: The version of this SoftwarePackageSummary.
        :type: str
        """
        self._version = version

    @property
    def architecture(self):
        """
        Gets the architecture of this SoftwarePackageSummary.
        the architecture for which this software was built


        :return: The architecture of this SoftwarePackageSummary.
        :rtype: str
        """
        return self._architecture

    @architecture.setter
    def architecture(self, architecture):
        """
        Sets the architecture of this SoftwarePackageSummary.
        the architecture for which this software was built


        :param architecture: The architecture of this SoftwarePackageSummary.
        :type: str
        """
        self._architecture = architecture

    @property
    def checksum(self):
        """
        Gets the checksum of this SoftwarePackageSummary.
        checksum of the package


        :return: The checksum of this SoftwarePackageSummary.
        :rtype: str
        """
        return self._checksum

    @checksum.setter
    def checksum(self, checksum):
        """
        Sets the checksum of this SoftwarePackageSummary.
        checksum of the package


        :param checksum: The checksum of this SoftwarePackageSummary.
        :type: str
        """
        self._checksum = checksum

    @property
    def checksum_type(self):
        """
        Gets the checksum_type of this SoftwarePackageSummary.
        type of the checksum


        :return: The checksum_type of this SoftwarePackageSummary.
        :rtype: str
        """
        return self._checksum_type

    @checksum_type.setter
    def checksum_type(self, checksum_type):
        """
        Sets the checksum_type of this SoftwarePackageSummary.
        type of the checksum


        :param checksum_type: The checksum_type of this SoftwarePackageSummary.
        :type: str
        """
        self._checksum_type = checksum_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateClusterOptionsDetails(object):
    """
    The properties that define extra options updating a cluster.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateClusterOptionsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param admission_controller_options:
            The value to assign to the admission_controller_options property of this UpdateClusterOptionsDetails.
        :type admission_controller_options: AdmissionControllerOptions

        """
        self.swagger_types = {
            'admission_controller_options': 'AdmissionControllerOptions'
        }

        self.attribute_map = {
            'admission_controller_options': 'admissionControllerOptions'
        }

        self._admission_controller_options = None

    @property
    def admission_controller_options(self):
        """
        Gets the admission_controller_options of this UpdateClusterOptionsDetails.
        Configurable cluster admission controllers


        :return: The admission_controller_options of this UpdateClusterOptionsDetails.
        :rtype: AdmissionControllerOptions
        """
        return self._admission_controller_options

    @admission_controller_options.setter
    def admission_controller_options(self, admission_controller_options):
        """
        Sets the admission_controller_options of this UpdateClusterOptionsDetails.
        Configurable cluster admission controllers


        :param admission_controller_options: The admission_controller_options of this UpdateClusterOptionsDetails.
        :type: AdmissionControllerOptions
        """
        self._admission_controller_options = admission_controller_options

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
